package com.xkrs.model.entity;

import javax.persistence.*;

/**
 * @author XinYi Song
 */
@Entity
@Table(name="fire")
public class FirePoint {
    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "fire_seq_gen")
    @SequenceGenerator(name = "fire_seq_gen", sequenceName = "fire_id_seq",allocationSize = 1)
    private Integer id;

    /**
     * 火点编码
     */
    @Column( length = 32,unique = true,columnDefinition = "varchar(32)")
    private String fireCode;

    /**
     * 经度
     */
    private double longitude;

    /**
     * 纬度
     */
    private double latitude;

    /**
     * 省市区的编码
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String countyCode;

    /**
     * 省市区的名称
     */
    @Column( columnDefinition = "varchar(64)")
    private String countyName;

    /**
     * 卫星监测的时间
     */
    private String satelliteTime;

    /**
     * 卫星的类型
     */
    @Column( columnDefinition = "varchar(64)")
    private String satelliteType;

    /**
     * 植被类型
     */
    @Column( columnDefinition = "varchar(64)")
    private String landType;

    /**
     * 添加的时间
     */
    private String addTime;

    /**
     * 置信度
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String confidence;

    /**
     * 详细地址
     */
    private String firePointAddress;

    /**
     * 火点状态 0 发现 1预警 2核查 -1,3结案
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String fireType;

    /**
     * 当前火点的图片
     */
    private String fireImage;

    /**
     * 卫星影像图片
     */
    private String satelliteImage;


    public FirePoint() {
    }

    public FirePoint(Integer id, String fireCode, double longitude, double latitude, String countyCode, String countyName, String satelliteTime, String satelliteType, String landType, String addTime, String confidence, String firePointAddress, String fireType, String fireImage, String satelliteImage) {
        this.id = id;
        this.fireCode = fireCode;
        this.longitude = longitude;
        this.latitude = latitude;
        this.countyCode = countyCode;
        this.countyName = countyName;
        this.satelliteTime = satelliteTime;
        this.satelliteType = satelliteType;
        this.landType = landType;
        this.addTime = addTime;
        this.confidence = confidence;
        this.firePointAddress = firePointAddress;
        this.fireType = fireType;
        this.fireImage = fireImage;
        this.satelliteImage = satelliteImage;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getFireCode() {
        return fireCode;
    }

    public void setFireCode(String fireCode) {
        this.fireCode = fireCode;
    }

    public double getLongitude() {
        return longitude;
    }

    public void setLongitude(double longitude) {
        this.longitude = longitude;
    }

    public double getLatitude() {
        return latitude;
    }

    public void setLatitude(double latitude) {
        this.latitude = latitude;
    }

    public String getCountyCode() {
        return countyCode;
    }

    public void setCountyCode(String countyCode) {
        this.countyCode = countyCode;
    }

    public String getCountyName() {
        return countyName;
    }

    public void setCountyName(String countyName) {
        this.countyName = countyName;
    }

    public String getSatelliteTime() {
        return satelliteTime;
    }

    public void setSatelliteTime(String satelliteTime) {
        this.satelliteTime = satelliteTime;
    }

    public String getSatelliteType() {
        return satelliteType;
    }

    public void setSatelliteType(String satelliteType) {
        this.satelliteType = satelliteType;
    }

    public String getLandType() {
        return landType;
    }

    public void setLandType(String landType) {
        this.landType = landType;
    }

    public String getAddTime() {
        return addTime;
    }

    public void setAddTime(String addTime) {
        this.addTime = addTime;
    }

    public String getConfidence() {
        return confidence;
    }

    public void setConfidence(String confidence) {
        this.confidence = confidence;
    }

    public String getFirePointAddress() {
        return firePointAddress;
    }

    public void setFirePointAddress(String firePointAddress) {
        this.firePointAddress = firePointAddress;
    }

    public String getFireType() {
        return fireType;
    }

    public void setFireType(String fireType) {
        this.fireType = fireType;
    }

    public String getFireImage() {
        return fireImage;
    }

    public void setFireImage(String fireImage) {
        this.fireImage = fireImage;
    }

    public String getSatelliteImage() {
        return satelliteImage;
    }

    public void setSatelliteImage(String satelliteImage) {
        this.satelliteImage = satelliteImage;
    }

    @Override
    public String toString() {
        return "FirePointEntity{" +
                "id=" + id +
                ", fireCode='" + fireCode + '\'' +
                ", longitude=" + longitude +
                ", latitude=" + latitude +
                ", countyCode='" + countyCode + '\'' +
                ", countyName='" + countyName + '\'' +
                ", satelliteTime='" + satelliteTime + '\'' +
                ", satelliteType='" + satelliteType + '\'' +
                ", landType='" + landType + '\'' +
                ", addTime='" + addTime + '\'' +
                ", confidence='" + confidence + '\'' +
                ", firePointAddress='" + firePointAddress + '\'' +
                ", fireType='" + fireType + '\'' +
                ", fireImage='" + fireImage + '\'' +
                ", satelliteImage='" + satelliteImage + '\'' +
                '}';
    }
}
